@@ -71,7 +71,7 @@
     <message>
         <location filename="../JupyterNotebook/preferences.ui" line="79"/>
         <source>If left empty, the jupyter-lab executable is autodetected and started with the home folder as the notebook folder.</source>
-        <translation>Par défaut, le fichier exécutable de jupyter-lab est détecté automatiquement et lancé avec le dossier de départ en tant que dossier de notebook</translation>
+        <translation>Par défaut, le fichier exécutable de jupyter-lab est détecté automatiquement et lancé avec le dossier de départ en tant que dossier de notebook.</translation>
     </message>
 </context>
 <context>
@@ -112,80 +112,105 @@
         <translation>Supprimer les espaces de fin automatiquement</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="100"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="117"/>
         <source>Rapunzel IDE: Keyboard shortcuts</source>
         <translation>Rapunzel IDE : Raccourcis clavier</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="124"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="141"/>
         <source>Run project or file</source>
         <translation>Exécuter projet ou fichier</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="131"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="148"/>
         <source>Run selection, cell, or current line</source>
         <translation>Exécuter la sélection, la cellule ou la ligne actuelle</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="138"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="155"/>
         <source>Interrupt kernel</source>
         <translation>Interrompre le noyau</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="145"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="162"/>
         <source>Change working directory to active file</source>
         <translation>Changer le répertoire de travail vers le fichier actuel</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="152"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="169"/>
         <source>Toggle fullscreen</source>
         <translation>Basculer mode plein écran</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="159"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="176"/>
         <source>Close tab</source>
         <translation>Fermer l&apos;onglet</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="166"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="183"/>
         <source>Close other tabs</source>
         <translation>Fermer les autres onglets</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="173"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="190"/>
         <source>Close all tabs</source>
         <translation>Fermer tous les onglets</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="180"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="197"/>
         <source>Split vertical</source>
         <translation>Division vertical</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="187"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="204"/>
         <source>Split horizontal</source>
         <translation>Division horizontal</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="194"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="211"/>
         <source>Switch to previous panel</source>
         <translation>Passer au panneau précedent</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="201"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="218"/>
         <source>Switch to next panel</source>
         <translation>Passer au panneau précedent</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="208"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="225"/>
         <source>Toggle folder browsers</source>
         <translation>Basculer les navigateurs de dossiers</translation>
     </message>
     <message>
-        <location filename="../OpenSesameIDE/preferences.ui" line="215"/>
+        <location filename="../OpenSesameIDE/preferences.ui" line="232"/>
         <source>Locate active file</source>
         <translation>Localiser le fichier actuel</translation>
     </message>
+    <message>
+        <location filename="../OpenSesameIDE/preferences.ui" line="97"/>
+        <source>Use system default file encoding</source>
+        <translation>Utiliser l&apos;encodage des fichiers par défaut du système</translation>
+    </message>
+    <message>
+        <location filename="../OpenSesameIDE/preferences.ui" line="107"/>
+        <source>Default file encoding</source>
+        <translation>Encodage des fichiers par défaut</translation>
+    </message>
+    <message>
+        <location filename="../OpenSesameIDE/preferences.ui" line="281"/>
+        <source>Run file in debugger</source>
+        <translation>Exécuter le fichier dans le débogueur</translation>
+    </message>
+    <message>
+        <location filename="../OpenSesameIDE/preferences.ui" line="288"/>
+        <source>Toggle breakpoint</source>
+        <translation>Basculer un point d&apos;arrêt</translation>
+    </message>
+    <message>
+        <location filename="../OpenSesameIDE/preferences.ui" line="295"/>
+        <source>Clear breakpoints</source>
+        <translation>Enlever les points d&apos;arret</translation>
+    </message>
 </context>
 <context>
     <name>SpellCheck_preferences</name>
@@ -256,12 +281,12 @@
 <context>
     <name>extension_CommandPalette</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="94"/>
+        <location filename="../../translation_tools/translatables.py" line="98"/>
         <source>Trigger menu actions</source>
         <translation>Activer les actions du menu</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="93"/>
+        <location filename="../../translation_tools/translatables.py" line="97"/>
         <source>Command palette</source>
         <translation>Palette de commandes</translation>
     </message>
@@ -269,7 +294,7 @@
 <context>
     <name>extension_DataViewer</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="5"/>
+        <location filename="../../translation_tools/translatables.py" line="3"/>
         <source>Load into workspace (DataMatrix) and view</source>
         <translation>Charger dans l&apos;espace de travail (DataMatrix) et afficher</translation>
     </message>
@@ -279,7 +304,7 @@
         <translation>DataViewer</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="3"/>
+        <location filename="../../translation_tools/translatables.py" line="5"/>
         <source>Load into workspace (PIL image) and view</source>
         <translation>Charger dans l&apos;espace de travail (image PIL) et afficher</translation>
     </message>
@@ -287,7 +312,7 @@
 <context>
     <name>extension_FindInFiles</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="8"/>
+        <location filename="../../translation_tools/translatables.py" line="10"/>
         <source>Find in project files</source>
         <translation>Rechercher dans les fichiers des projets</translation>
     </message>
@@ -297,12 +322,12 @@
         <translation>Trouver du text dans les fichiers des projets</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="10"/>
+        <location filename="../../translation_tools/translatables.py" line="11"/>
         <source>FindInFiles requires the OpenSesameIDE extension</source>
         <translation>FindInFiles à besoin de l&apos;extension OpenSesameIDE</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="11"/>
+        <location filename="../../translation_tools/translatables.py" line="8"/>
         <source>Find in projects</source>
         <translation>Recherchers dans les projets</translation>
     </message>
@@ -310,17 +335,17 @@
 <context>
     <name>extension_GitGUI</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="117"/>
+        <location filename="../../translation_tools/translatables.py" line="125"/>
         <source>Start Git GUI</source>
         <translation>Démarrer Git GUI</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="116"/>
+        <location filename="../../translation_tools/translatables.py" line="126"/>
         <source>Starts Git GUI</source>
         <translation>Démarre Git GUI</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="115"/>
+        <location filename="../../translation_tools/translatables.py" line="124"/>
         <source>Launch Git GUI</source>
         <translation>Lancer Git GUI</translation>
     </message>
@@ -328,60 +353,65 @@
 <context>
     <name>extension_JupyterConsole</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="123"/>
+        <location filename="../../translation_tools/translatables.py" line="133"/>
         <source>Show Jupyter/ IPython console</source>
         <translation>Montrer la console Jupyter/ IPython</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="120"/>
+        <location filename="../../translation_tools/translatables.py" line="129"/>
         <source>Restart kernel</source>
         <translation>Redémarrer le noyau</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="122"/>
+        <location filename="../../translation_tools/translatables.py" line="130"/>
         <source>Start new console</source>
         <translation>Lancer une nouvelle console</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="121"/>
+        <location filename="../../translation_tools/translatables.py" line="131"/>
         <source>Show console</source>
         <translation>Montrer la console</translation>
     </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="132"/>
+        <source>The {} (inprocess={}) kernel does not support debugging</source>
+        <translation>Le noyau {} (inprocess={}) ne prend pas en charge le débogage</translation>
+    </message>
 </context>
 <context>
     <name>extension_JupyterNotebook</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="87"/>
+        <location filename="../../translation_tools/translatables.py" line="93"/>
         <source>Open Jupyter/ IPython Notebook</source>
         <translation>Ouvrir Notebook Jupyter/ IPython</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="86"/>
+        <location filename="../../translation_tools/translatables.py" line="90"/>
         <source>Import notebook</source>
         <translation>Importer notebook</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="88"/>
+        <location filename="../../translation_tools/translatables.py" line="92"/>
         <source>Failed to read notebook. See console for details.</source>
         <translation>Le chargement du notebook à échoué. Voir la console pour plus de details.</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="89"/>
+        <location filename="../../translation_tools/translatables.py" line="94"/>
         <source>Launch Jupyter Lab</source>
         <translation>Démarrer Jupyter Lab</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="90"/>
+        <location filename="../../translation_tools/translatables.py" line="89"/>
         <source>Export notebook</source>
         <translation>Exporter notebook</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="84"/>
+        <location filename="../../translation_tools/translatables.py" line="88"/>
         <source>Import and export Jupyter Notebook (.ipynb) files</source>
         <translation>Importer et exporter des fichiers Jupyter Notebook (.ipynb)</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="85"/>
+        <location filename="../../translation_tools/translatables.py" line="91"/>
         <source>Import as Python script</source>
         <translation>Importer en tant que script de Python</translation>
     </message>
@@ -389,32 +419,32 @@
 <context>
     <name>extension_OpenSesameIDE</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="45"/>
+        <location filename="../../translation_tools/translatables.py" line="54"/>
         <source>Open file</source>
         <translation>Ouvrir un fichier</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="73"/>
+        <location filename="../../translation_tools/translatables.py" line="80"/>
         <source>&amp;Save</source>
         <translation>&amp;Enregistrer</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="63"/>
+        <location filename="../../translation_tools/translatables.py" line="34"/>
         <source>&amp;Tools</source>
         <translation>&amp;Outils</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="33"/>
+        <location filename="../../translation_tools/translatables.py" line="51"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="27"/>
+        <location filename="../../translation_tools/translatables.py" line="25"/>
         <source>&amp;View</source>
         <translation>&amp;Vue</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="26"/>
+        <location filename="../../translation_tools/translatables.py" line="76"/>
         <source>&amp;Interrupt kernel</source>
         <translation>&amp;Interrompre le noyau</translation>
     </message>
@@ -424,207 +454,207 @@
         <translation>Pas d&apos;indexation de {} (trop de fichiers)</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="41"/>
+        <location filename="../../translation_tools/translatables.py" line="55"/>
         <source>Running notebook cell</source>
         <translation>Exécuter cellule de notebook</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="42"/>
+        <location filename="../../translation_tools/translatables.py" line="49"/>
         <source>Split &amp;vertical</source>
         <translation>Division &amp;vertical</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="57"/>
+        <location filename="../../translation_tools/translatables.py" line="71"/>
         <source>Fixed editor width</source>
         <translation>Largeur de l&apos;éditeur fixée</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="55"/>
+        <location filename="../../translation_tools/translatables.py" line="82"/>
         <source>Run &amp;selection, cell, or current line</source>
         <translation>Exécuter la &amp;sélection, la cellule ou la ligne actuelle</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="46"/>
+        <location filename="../../translation_tools/translatables.py" line="27"/>
         <source>Running current line</source>
         <translation>En train d&apos;exécuter la ligne actuelle</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="28"/>
+        <location filename="../../translation_tools/translatables.py" line="59"/>
         <source>How do you want to open this file?</source>
         <translation>Comment voulez-vous ouvrir ce fichier ?</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="69"/>
+        <location filename="../../translation_tools/translatables.py" line="79"/>
         <source>Close &amp;all tabs</source>
         <translation>Fermer &amp;tous les onglets</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="61"/>
+        <location filename="../../translation_tools/translatables.py" line="53"/>
         <source>Code completion</source>
         <translation>Complétion de code</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="70"/>
+        <location filename="../../translation_tools/translatables.py" line="36"/>
         <source>&amp;Locate active file</source>
         <translation>&amp;Localiser le fichier actuel</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="48"/>
+        <location filename="../../translation_tools/translatables.py" line="58"/>
         <source>Select indentation mode</source>
         <translation>Sélectionner le mode d&apos;indentation</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="56"/>
+        <location filename="../../translation_tools/translatables.py" line="30"/>
         <source>Wrap lines</source>
         <translation>Retour à ligne</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="62"/>
+        <location filename="../../translation_tools/translatables.py" line="64"/>
         <source>Open as text</source>
         <translation>Ouvrir comme texte</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="54"/>
+        <location filename="../../translation_tools/translatables.py" line="28"/>
         <source>&amp;New</source>
         <translation>&amp;Nouveau</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="36"/>
+        <location filename="../../translation_tools/translatables.py" line="72"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="53"/>
+        <location filename="../../translation_tools/translatables.py" line="45"/>
         <source>Switch to previous panel</source>
         <translation>Passer au panneau précedent</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="68"/>
+        <location filename="../../translation_tools/translatables.py" line="41"/>
         <source>&amp;Preferences</source>
         <translation>&amp;Préférences</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="75"/>
+        <location filename="../../translation_tools/translatables.py" line="66"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="59"/>
+        <location filename="../../translation_tools/translatables.py" line="31"/>
         <source>Code folding</source>
         <translation>Pliage de code</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="66"/>
+        <location filename="../../translation_tools/translatables.py" line="48"/>
         <source>Turn OpenSesame into an IDE</source>
         <translation>Changer OpenSesame en IDE</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="64"/>
+        <location filename="../../translation_tools/translatables.py" line="42"/>
         <source>P&amp;lugins</source>
         <translation>P&amp;lugins</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="40"/>
+        <location filename="../../translation_tools/translatables.py" line="39"/>
         <source>Switch to next panel</source>
         <translation>Passer au panneau suivant</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="25"/>
+        <location filename="../../translation_tools/translatables.py" line="60"/>
         <source>Running project</source>
         <translation>En train d&apos;exécuter le projet</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="37"/>
+        <location filename="../../translation_tools/translatables.py" line="52"/>
         <source>Close &amp;other tabs</source>
         <translation>Fermer les &amp;autres onglets</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="38"/>
+        <location filename="../../translation_tools/translatables.py" line="74"/>
         <source>&amp;Run</source>
         <translation>&amp;Exécuter</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="24"/>
+        <location filename="../../translation_tools/translatables.py" line="70"/>
         <source>&amp;Close tab</source>
         <translation>&amp;Fermer l&apos;onglet</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="43"/>
+        <location filename="../../translation_tools/translatables.py" line="47"/>
         <source>Restart &amp;kernel</source>
         <translation>Redémarrer le &amp;noyau</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="77"/>
+        <location filename="../../translation_tools/translatables.py" line="68"/>
         <source>Save and run</source>
         <translation>Enregistrer et exécuter</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="67"/>
+        <location filename="../../translation_tools/translatables.py" line="38"/>
         <source>Show right margin</source>
         <translation>Montrer la marge droite</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="51"/>
+        <location filename="../../translation_tools/translatables.py" line="77"/>
         <source>Running file</source>
         <translation>En train d&apos;exécuter le fichier</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="60"/>
+        <location filename="../../translation_tools/translatables.py" line="81"/>
         <source>Split &amp;horizontal</source>
         <translation>Division &amp;horizontal</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="49"/>
+        <location filename="../../translation_tools/translatables.py" line="69"/>
         <source>Show editor tabs</source>
         <translation>Montrer les onglets de l&apos;éditeur</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="52"/>
+        <location filename="../../translation_tools/translatables.py" line="65"/>
         <source>Unsaved changes</source>
         <translation>Modifications non enregistrées</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="29"/>
+        <location filename="../../translation_tools/translatables.py" line="78"/>
         <source>Running selection</source>
         <translation>En train d&apos;exécuter la sélection</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="44"/>
+        <location filename="../../translation_tools/translatables.py" line="26"/>
         <source>Show whitespace</source>
         <translation>Montrer les espaces</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="78"/>
+        <location filename="../../translation_tools/translatables.py" line="50"/>
         <source>&amp;Close all folders</source>
         <translation>&amp;Fermer tous les navigateurs de dossiers</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="72"/>
+        <location filename="../../translation_tools/translatables.py" line="35"/>
         <source>Show line numbers</source>
         <translation>Montrer les numéros des lignes</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="74"/>
+        <location filename="../../translation_tools/translatables.py" line="29"/>
         <source>Toggle fullscreen</source>
         <translation>Basculer mode plein écran</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="31"/>
+        <location filename="../../translation_tools/translatables.py" line="67"/>
         <source>&amp;Editor</source>
         <translation>&amp;Éditeur</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="58"/>
+        <location filename="../../translation_tools/translatables.py" line="43"/>
         <source>&amp;Run project or file</source>
         <translation>&amp;Exécuter projet ou fichier</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="71"/>
+        <location filename="../../translation_tools/translatables.py" line="56"/>
         <source>Change &amp;working directory to active file</source>
         <translation>Changer le &amp;répertoire de travail vers le fichier actuel</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="65"/>
+        <location filename="../../translation_tools/translatables.py" line="75"/>
         <source>Toggle &amp;folder browsers</source>
         <translation>Basculer les &amp;navigateurs de dossiers</translation>
     </message>
@@ -659,50 +689,83 @@
         <translation type="obsolete">Enregistrer &amp;sous…</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="35"/>
+        <location filename="../../translation_tools/translatables.py" line="63"/>
         <source>Save, run, and don&apos;t ask again</source>
         <translation>Enregistrer, exécuter, et ne plus demander</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="34"/>
+        <location filename="../../translation_tools/translatables.py" line="73"/>
         <source>Search project files or browse disk …</source>
         <translation>Rechercher dans les fichiers des projets ou parcourir le disque …</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="30"/>
+        <location filename="../../translation_tools/translatables.py" line="57"/>
         <source>Save &amp;as…</source>
         <translation>Enregistrer &amp;sous…</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="76"/>
+        <location filename="../../translation_tools/translatables.py" line="44"/>
         <source>Browse disk …</source>
         <translation>Parcourir le disque …</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="39"/>
+        <location filename="../../translation_tools/translatables.py" line="33"/>
         <source>Open &amp;folder…</source>
         <translation>Ouvrir un &amp;dossier…</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="47"/>
+        <location filename="../../translation_tools/translatables.py" line="24"/>
         <source>&amp;Open…</source>
         <translation>&amp;Ouvrir…</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="50"/>
+        <location filename="../../translation_tools/translatables.py" line="61"/>
         <source>Search recent folders or browse disk …</source>
         <translation>Parcourir</translation>
     </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="46"/>
+        <source>Cannot save file with this encoding</source>
+        <translation>Ne peut pas enregistrer le fichier avec cet encodage</translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="62"/>
+        <source>Run file in &amp;debugger</source>
+        <translation>Exécuter le fichier dans le &amp;débogueur</translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="40"/>
+        <source>Clear &amp;breakpoints</source>
+        <translation>Enlever les &amp;points d&apos;arret</translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="37"/>
+        <source>&amp;Toggle breakpoint</source>
+        <translation>&amp;Basculer un point d&apos;arrêt</translation>
+    </message>
+</context>
+<context>
+    <name>extension_PythonDebugger</name>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="106"/>
+        <source>Connects to the Rapunzel PDB</source>
+        <translation>Se connecte avec le débogueur Rapunzel</translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="105"/>
+        <source>Python Debugger</source>
+        <translation>Débogueur Python</translation>
+    </message>
 </context>
 <context>
     <name>extension_QuickSelector</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="15"/>
+        <location filename="../../translation_tools/translatables.py" line="14"/>
         <source>A general-purpose quick-select dialog</source>
         <translation>Une boîte de dialogue de sélection rapide à usage général</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="14"/>
+        <location filename="../../translation_tools/translatables.py" line="15"/>
         <source>Select stuff quickly</source>
         <translation>Sélectionner des choses rapidement</translation>
     </message>
@@ -710,7 +773,7 @@
 <context>
     <name>extension_RapunzelLocale</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="101"/>
+        <location filename="../../translation_tools/translatables.py" line="109"/>
         <source>Installs translation for Rapunzel extensions</source>
         <translation>Installe la traduction des extensions Rapunzel</translation>
     </message>
@@ -718,12 +781,12 @@
 <context>
     <name>extension_RapunzelWelcome</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="97"/>
+        <location filename="../../translation_tools/translatables.py" line="102"/>
         <source>Get started!</source>
         <translation>Lancez-vous !</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="98"/>
+        <location filename="../../translation_tools/translatables.py" line="101"/>
         <source>A welcome tab for Rapunzel</source>
         <translation>Un onglet de bienvenue pour Rapunzel</translation>
     </message>
@@ -731,7 +794,7 @@
 <context>
     <name>extension_SpellCheck</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="81"/>
+        <location filename="../../translation_tools/translatables.py" line="85"/>
         <source>Check spelling</source>
         <translation>Vérifier l&apos;ortographe</translation>
     </message>
@@ -739,17 +802,17 @@
 <context>
     <name>extension_SymbolSelector</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="111"/>
+        <location filename="../../translation_tools/translatables.py" line="121"/>
         <source>Symbol selector</source>
         <translation>Sélecteur de symboles</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="112"/>
+        <location filename="../../translation_tools/translatables.py" line="120"/>
         <source>Quickly jump to functions, classes, and other symbol definitions</source>
         <translation>Accédez rapidement aux fonctions, classes et autres définitions de symboles</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="110"/>
+        <location filename="../../translation_tools/translatables.py" line="119"/>
         <source>Search symbols in current file …</source>
         <translation>Rechercher des symboles dans le fichier actuel …</translation>
     </message>
@@ -757,22 +820,22 @@
 <context>
     <name>extension_WordCount</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="20"/>
+        <location filename="../../translation_tools/translatables.py" line="18"/>
         <source>Word count</source>
         <translation>Nombre de mot</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="21"/>
+        <location filename="../../translation_tools/translatables.py" line="19"/>
         <source>{} lines, {} words, {} characters</source>
         <translation>{} lignes, {} mots, {} caractères</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="18"/>
+        <location filename="../../translation_tools/translatables.py" line="20"/>
         <source>Nothing to count</source>
         <translation>Rien à compter</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="19"/>
+        <location filename="../../translation_tools/translatables.py" line="21"/>
         <source>Counts the number of lines, words, and characters</source>
         <translation>Compte le nombre de lignes, de mots et de caractères</translation>
     </message>
@@ -780,25 +843,30 @@
 <context>
     <name>extension_WorkspaceExplorer</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="106"/>
+        <location filename="../../translation_tools/translatables.py" line="112"/>
         <source>Workspace ({})</source>
         <translation>Espace de travail ({})</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="107"/>
+        <location filename="../../translation_tools/translatables.py" line="114"/>
         <source>Show Python workspace explorer</source>
         <translation>Afficher l&apos;explorateur d&apos;espace de travail Python</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="104"/>
+        <location filename="../../translation_tools/translatables.py" line="113"/>
         <source>Show workspace</source>
         <translation>Afficher l&apos;espace de travail</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="105"/>
+        <location filename="../../translation_tools/translatables.py" line="116"/>
         <source>Workspace</source>
         <translation>Espace de travail</translation>
     </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="115"/>
+        <source>Cannot inspect variables in running kernel</source>
+        <translation>Ne peut pas visualiser des variables à partir d&apos;un noyau en cours d&apos;exécution</translation>
+    </message>
 </context>
 <context>
     <name>find_in_files</name>
